function y=itraiz(c,d,v,x)
%
% function y=itraiz(c,d,v,x)
%
%     Copyright: Eduardo Casas (Febrero, 1995)
%
% Funcion que realiza una iteración del método de Maehly
% Variables de Entrada:
%
% c      Coeficientes del polinomio cuya raiz se desea calcular.
% d      Coeficientes del polinomio derivada.
% v      Vector que contiene las raices ya calculadas.
% x      Punto sobre el que se desea iterar.
%
% Variable de Salida:
%
% y      Resultado de la iteración.
%
n=length(v);
px=polyval(c,x);
if n==0,
    y=x-px/polyval(d,x);
else
    s=sum(1./(x-v));
    y=x-px/(polyval(d,x)-px*s);
end